/*
 * Export a panel structure.
 *
 * (c) 2018 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/devices/lcd-jz4740-config.h>
#include <l4/devices/lcd-jz4740-panel.h>
#include "panel-server.h"

#include <l4/re/util/object_registry>

static struct Jz4740_lcd_panel panel = {
  .config = (
      Jz4740_lcd_mode_tft_generic
    | Jz4740_lcd_pclock_negative
    | Jz4740_lcd_hsync_negative
    | Jz4740_lcd_vsync_negative
    | Jz4740_lcd_de_positive),

  .width = 800,
  .height = 480,
  .bpp = 16,
  .frame_rate = 60,
  .hsync = 80,
  .vsync = 20,
  .line_start = 0,
  .line_end = 0,
  .frame_start = 0,
  .frame_end = 0,
};

static L4Re::Util::Registry_server<> server;

int main(void)
{
  /* Initialise and register a new server object. */

  Panel_server server_obj(&panel, sizeof(panel));
  server.registry()->register_obj(&server_obj, "panel");

  /* Enter the IPC server loop. */

  server.loop();
  return 0;
}
